package com.biganto.visual.roompark.domain.interactor

import com.biganto.visual.roompark.domain.model.ArticlePreviewModel
import com.biganto.visual.roompark.domain.model.ArticlesPreviewModel
import com.biganto.visual.roompark.domain.model.FeedModel
import com.biganto.visual.roompark.domain.model.FeedsHeaderModel
import io.reactivex.Single
import java.util.*
import javax.inject.Inject

/**
 * Created by Vladislav Bogdashkin on 09.10.2019.
 */

class FeedsInteractor @Inject constructor(
) {

    fun fetchTopFeeds(): Single<FeedsHeaderModel> = Single.just(testFeeds)

    fun fetchArticles(feedId: Int): Single<ArticlesPreviewModel> = Single.just(
        when (feedId) {
            1 -> testNewsArticles
            2 -> testBlogsArticles
            3 -> testDevArticles
            else -> error("unknown feedId")
        }
    )


    private companion object {

        private const val sampleUrl: String =
            "https://room-park.ru/assets/news_articles/preview/00/00/00/109-8c9b72.jpeg"
        private const val sampleUrlB =
            "https://room-park.ru/assets/news_articles/preview/00/00/00/104-2b4eff.jpeg"
        private const val sampleUrlDev =
            "https://room-park.ru/assets/news_articles/preview/00/00/00/96-a972cd.jpeg"

        val testFeeds = FeedsHeaderModel(
            listOf(
                FeedModel(1, "НОВОСТИ"),
                FeedModel(2, "БЛОГИ"),
                FeedModel(2, "БЛОГ СТРОИТЕЛЬСТВА")
            )
        )

        val testNewsArticles = ArticlesPreviewModel(
            1,
            listOf(
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Первая новость"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrl
                    , false
                ),
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Первая новость"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrl
                    , false
                ),
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Первая новость"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrl
                    , false
                )
            )
        )

        val testBlogsArticles = ArticlesPreviewModel(
            2,
            listOf(
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Первая новость"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrlB
                    , false
                ),
                ArticlePreviewModel(
                    1
                    , Date()
                    , "НОВЫЙ ОФИС ПРОДАЖ ЖК «РУМЯНЦЕВО-ПАРК»"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrlB
                    , false
                ),
                ArticlePreviewModel(
                    1
                    , Date()
                    , "В «РУМЯНЦЕВО-ПАРК» ПРИСТУПИЛИ К МОНТАЖУ ОКОННЫХ БЛОКОВ"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrlB
                    , false
                )
            )
        )

        val testDevArticles = ArticlesPreviewModel(
            3,
            listOf(
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Ход1"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrlDev
                    , false
                ),
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Ход2"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrlDev
                    , false
                ),
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Ход3"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrlDev
                    , false
                )
            )
        )
    }
}



