package com.biganto.visual.roompark.presentation.screen.feeds

import com.biganto.visual.roompark.conductor.BigantoBasePresenter
import com.biganto.visual.roompark.domain.interactor.FeedsInteractor
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.schedulers.Schedulers
import timber.log.Timber
import javax.inject.Inject

/**
 * Created by Vladislav Bogdashkin on 30.09.2019.
 */


class FeedsScreenPresenter @Inject constructor(
    private val interactor: FeedsInteractor
)
    : BigantoBasePresenter<FeedsScreen, FeedsScreenViewState>() {


    override fun bindIntents() {

        val fetchFeeds = interactor.fetchTopFeeds()
            .map {FeedsScreenViewState.FeedsPages(it.feeds.toList()) }

        val state = restoreStateObservable
            .mergeWith(fetchFeeds)
            .doOnError{ Timber.e(it)}
            .subscribeOn(Schedulers.io())
            .observeOn(AndroidSchedulers.mainThread())

        subscribeViewState(state.cast(FeedsScreenViewState::class.java), FeedsScreen::render)
    }

}